pub struct PoolBuilder<DB: Database> { /* private fields */ }Expand description
Builder for configuring a Pool before connecting.
Created via Pool::builder().
Implementations
Sourceimpl<DB: Database> PoolBuilder<DB>
impl<DB: Database> PoolBuilder<DB>
Sourcepub fn max_connections(self, max: u32) -> Self
pub fn max_connections(self, max: u32) -> Self
Set the maximum number of connections the pool should maintain.
Sourcepub fn min_connections(self, min: u32) -> Self
pub fn min_connections(self, min: u32) -> Self
Set the minimum number of connections the pool should maintain.
Sourcepub fn idle_timeout(self, timeout: Duration) -> Self
pub fn idle_timeout(self, timeout: Duration) -> Self
Set the maximum time a connection can sit idle before being closed.
Sourcepub fn max_lifetime(self, lifetime: Duration) -> Self
pub fn max_lifetime(self, lifetime: Duration) -> Self
Set the maximum lifetime of individual connections.
Sourcepub fn acquire_timeout(self, timeout: Duration) -> Self
pub fn acquire_timeout(self, timeout: Duration) -> Self
Set the maximum time to wait when acquiring a connection from the pool.